@@ -39,7 +39,7 @@ author_email       = "rocky@gnu.org"
 ftp_url            = None
 install_requires   = ['columnize >= 0.3.2', 
                       'import_relative >= 0.1.0',
-                      'pyficache >= 0.1.5',
+                      'pyficache >= 0.2.01',
                       'pygments',
                       'tracer >= 0.2.2']
 license            = 'GPL'
@@ -47,7 +47,7 @@ mailing_list       = 'python-debugger@googlegroups.com'
 modname            = 'pydbgr'
 namespace_packages = [
     'pydbgr', 
-    'pydbgr.interface',
+    'pydbgr.interfaces',
     'pydbgr.io',
     'pydbgr.lib',
     'pydbgr.processor',
