@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2012 Rocky Bernstein
+#   Copyright (C) 2009, 2012, 2013 Rocky Bernstein
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
@@ -14,15 +14,19 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 '''Disassembly Routines'''
 
-import inspect, sys, types
+import inspect, pygments, sys, types
 from dis import distb, findlabels, findlinestarts
 from opcode import cmp_op, hasconst, hascompare, hasfree, hasname, hasjrel, \
     haslocal, opname, EXTENDED_ARG, HAVE_ARGUMENT
 
-# Modified from dis. Changed output to use msg and msg_nocr.
+from import_relative import import_relative
+Mformat   = import_relative('format', top_name='pydbgr')
+format_token = Mformat.format_token
+
+# Modified from dis. Changed output to use msg, msg_nocr, section, and pygments.
 # Added first_line and last_line parameters
 def dis(msg, msg_nocr, section, errmsg, x=None, start_line=-1, end_line=None,
-        relative_pos = False):
+        relative_pos = False, color=True):
     """Disassemble classes, methods, functions, or code.
 
     With no argument, disassemble the last traceback.
@@ -58,14 +62,14 @@ def dis(msg, msg_nocr, section, errmsg, x=None, start_line=-1, end_line=None,
                             types.CodeType,
                             types.ClassType):
                 try:
-                    dis(msg, msg_nocr, errmsg, x1, 
+                    dis(msg, msg_nocr, errmsg, section, x1, 
                         start_line=start_line, end_line=end_line, 
                         relative_pos = relative_pos)
                     msg("")
                 except TypeError, msg:
                     errmsg("Sorry:", msg)
     elif hasattr(x, 'co_code'):
-        disassemble(msg, msg_nocr, x, lasti=lasti, 
+        disassemble(msg, msg_nocr, section, x, lasti=lasti, 
                     start_line=start_line, end_line=end_line,
                     relative_pos = relative_pos)
     elif isinstance(x, str):
@@ -75,20 +79,20 @@ def dis(msg, msg_nocr, section, errmsg, x=None, start_line=-1, end_line=None,
               type(x).__name__)
     return
 
-def disassemble(msg, msg_nocr, co, lasti=-1, start_line=-1, end_line=None,
-                relative_pos=False):
+def disassemble(msg, msg_nocr, section, co, lasti=-1, start_line=-1, end_line=None,
+                relative_pos=False, color='light'):
     """Disassemble a code object."""
     disassemble_string(msg, msg_nocr, co.co_code, lasti, co.co_firstlineno,
                        start_line, end_line, relative_pos,
                        co.co_varnames, co.co_names, co.co_consts,
                        co.co_cellvars, co.co_freevars,
-                       dict(findlinestarts(co)))
+                       dict(findlinestarts(co)), color)
     return
 
 def disassemble_string(orig_msg, orig_msg_nocr, code, lasti=-1, cur_line=0,
                        start_line=-1, end_line=None, relative_pos=False,
                        varnames=(), names=(), consts=(), cellvars=(),
-                       freevars=(), linestarts={}):
+                       freevars=(), linestarts={}, color='light'):
     """Disassemble byte string of code. If end_line is negative
     it counts the number of statement linestarts to use."""
     statement_count = 10000
@@ -126,17 +130,23 @@ def disassemble_string(orig_msg, orig_msg_nocr, code, lasti=-1, cur_line=0,
                 msg = orig_msg
                 pass
             if cur_line > end_line: break
-            msg_nocr("%3d" % cur_line)
+            msg_nocr(format_token(Mformat.LineNumber,
+                                  "%3d" % cur_line,
+                                  highlight=color))
         else:
             msg_nocr('   ')
 
-        if i == lasti: msg_nocr('-->')
+        if i == lasti: msg_nocr(format_token(Mformat.Arrow, '-->',
+                                             highlight=color))
         else: msg_nocr('   ')
-        if i in labels: msg_nocr('>>')
+        if i in labels: msg_nocr(format_token(Mformat.Arrow, '>>',
+                                              highlight=color))
         else: msg_nocr('  ')
         msg_nocr(repr(i).rjust(4))
         msg_nocr(' ')
-        msg_nocr(opname[op].ljust(20))
+        msg_nocr(format_token(Mformat.Opcode,
+                              opname[op].ljust(20),
+                              highlight=color))
         i += 1
         if op >= HAVE_ARGUMENT:
             oparg = ord(code[i]) + ord(code[i+1])*256 + extended_arg
@@ -147,15 +157,32 @@ def disassemble_string(orig_msg, orig_msg_nocr, code, lasti=-1, cur_line=0,
             msg_nocr(repr(oparg).rjust(5))
             msg_nocr(' ')
             if op in hasconst:
-                msg_nocr('(' + repr(consts[oparg]) + ')')
+                msg_nocr('(' +
+                         format_token(Mformat.Const,
+                                      repr(consts[oparg]),
+                                      highlight=color)
+                         + ')')
+                pass
             elif op in hasname:
-                msg_nocr('(' + names[oparg] + ')')
+                msg_nocr('(' +
+                         format_token(Mformat.Name,
+                                      names[oparg],
+                                      highlight=color)
+                         + ')')
             elif op in hasjrel:
-                msg_nocr('(to ' + repr(i + oparg) + ')')
+                msg_nocr(format_token(Mformat.Label,
+                                      '(to ' + repr(i + oparg) + ')',
+                                      highlight=color))
             elif op in haslocal:
-                msg_nocr('(' + varnames[oparg] + ')')
+                msg_nocr('(' +
+                         format_token(Mformat.Var,
+                                      varnames[oparg],
+                                      highlight=color) + ')')
             elif op in hascompare:
-                msg_nocr('(' + cmp_op[oparg] + ')')
+                msg_nocr('(' +
+                         format_token(Mformat.Compare,
+                                      cmp_op[oparg],
+                                      highlight=color) + ')')
             elif op in hasfree:
                 if free is None:
                     free = cellvars + freevars
@@ -189,13 +216,16 @@ if __name__ == '__main__':
     def errmsg(msg_str):
         msg('*** ' + msg_str)
         return
+    def section(msg_str):
+        msg('=== ' + msg_str + ' ===')
+        return
     curframe = inspect.currentframe()
-    dis(msg, msg_nocr, errmsg, curframe,
+    dis(msg, msg_nocr, errmsg, section, curframe,
         start_line=10, end_line=40)
     print '-' * 40
-    dis(msg, msg_nocr, errmsg, disassemble)
+    dis(msg, msg_nocr, section, errmsg, disassemble)
     print '-' * 40
     magic, moddate, modtime, co = pyc2code(sys.modules['types'].__file__)
-    disassemble(msg, msg_nocr, co, -1, 1, 70)
+    disassemble(msg, msg_nocr, section, co, -1, 1, 70)
     pass
 
