@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2008, 2009, 2010, 2012 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008-2010, 2012-2013 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -15,9 +15,15 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 NotImplementedMessage = "This method must be overriden in a subclass"
 from pygments.console import colorize
+from import_relative import import_relative
+Mformat = import_relative('format',  '..lib', 'pydbgr')
+
+__all__ = ['Processor']
+
 class Processor:
-    """ A processor is the thing that handles the events that come to the debugger.
-    It has it's own I/O mechanism and a way to handle the events.
+    """A processor is the thing that handles the events that come to
+    the debugger.  It has it's own I/O mechanism and a way to handle
+    the events.
     """
     def __init__(self, core_obj):
         self.core = core_obj
@@ -32,7 +38,7 @@ class Processor:
     # we wouldn't pick up that change in our self.msg
     def errmsg(self, message, opts={}):
         """ Convenience short-hand for self.intf[-1].errmsg """
-        if 'terminal' == self.core.debugger.settings['highlight']:
+        if 'plain' != self.debugger.settings['highlight']:
             message = colorize('standout', message)
             pass
         return(self.intf[-1].errmsg(message))
@@ -48,11 +54,18 @@ class Processor:
     def event_processor(self, frame, event, arg):
         raise NotImplementedError, NotImplementedMessage
 
+    def rst_msg(self, text, opts={}):
+        """Convert ReStructuredText and run through msg()"""
+        text = Mformat.rst_text(text,
+                                'plain' == self.debugger.settings['highlight'],
+                                self.debugger.settings['width'])
+        return self.msg(text)
+               
     def section(self, message, opts={}):
-        if 'terminal' == self.settings['highlight']:
+        if 'plain' != self.settings('highlight'):
             message = colorize('bold', message)
             pass
-        self.msg(message, opts)
+        return self.msg(message, opts)
 
     def settings(self, setting):
         return self.core.debugger.settings[setting]
