@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2010, 2012 Rocky Bernstein
+#   Copyright (C) 2009-2010, 2012-2013 Rocky Bernstein
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,11 +30,12 @@ class DebuggerSubcommand:
     """Base Class for Debugger subcommands. We pull in some helper
     functions for command from module cmdfns."""
 
-    in_list    = True  # Show item in help list of commands
-    run_cmd    = True  # Run subcommand for those subcommands like "show"
-                       # which append current settings to list output.
-    min_abbrev = 1
-    need_stack = False
+    in_list     = True  # Show item in help list of commands
+    run_cmd     = True  # Run subcommand for those subcommands like "show"
+                        # which append current settings to list output.
+    run_in_help = True  # Run to get value in 'show' command?
+    min_abbrev  = 1
+    need_stack  = False
 
     def __init__(self, cmd):
         """cmd contains the command object that this
@@ -91,6 +92,10 @@ class DebuggerSubcommand:
     aliases = ('alias1', 'alias2..',)
     name    = 'YourCommandName'
         
+    def rst_msg(self, text):
+        """Convenience short-hand for self.proc.rst_msg(text)"""
+        return(self.proc.rst_msg(text))
+
     def run(self):
         """ The method that implements the debugger command.
         Help on the command comes from the docstring of this method.
@@ -98,7 +103,7 @@ class DebuggerSubcommand:
         raise NotImplementedError, NotImplementedMessage
 
     def section(self, message, opts={}):
-        if 'terminal' == self.settings['highlight']:
+        if 'plain' != self.settings['highlight']:
             message = colorize('bold', message)
             pass
         self.msg(message)
